"use client";
import man from "@/assets/images/ellipse-113@2x.png";
import man_one from "@/assets/images/man_one.png";
import woman from "@/assets/images/woman.png";
import star from "@/assets/star-6.svg";
import upArrow from "@/assets/vector7.svg";
import downArrow from "@/assets/vector8.svg";
import Image from "next/image";
import { useRef, useState } from "react";
import "swiper/css";
import "swiper/css/navigation";
import "swiper/css/pagination";
import { HashNavigation, Navigation, Pagination } from "swiper/modules";
import { Swiper, SwiperSlide } from "swiper/react";

const customers = [
  { name: "Kell Robinson", role: "Product Manager", image: man_one, index: 0 },
  { name: "Jack Nitzsche", role: "Product Manager", image: man, index: 1 },
  { name: "Karen Maria", role: "Product Manager", image: woman, index: 2 },
];

const testimonials = [
  "Purchasing our dream home was made incredibly simple thanks to the dedicated team at Fund Verify. From start to finish, their professionalism and commitment to finding us the perfect property were unmatched. We couldn't be happier with our new home!",
  "The experience of buying a car at Fund Verify was nothing short of exceptional. The sales team was knowledgeable, patient, and helped us find a car that perfectly matched our needs and budget. We highly recommend them to anyone looking for a new vehicle!",
  "As first-time boat buyers, we were a bit overwhelmed, but Fund Verify made the entire process smooth and enjoyable. Their expertise and customer service were top-notch, and we're thrilled with our new boat. Thank you for making our dream a reality!",
  "Finding the perfect engagement ring was a memorable experience thanks to Fund Verify. Their collection is stunning, and the staff was incredibly helpful in guiding us through our options. We are extremely happy with our purchase and will definitely return for future jewelry needs.",
  "The selection and quality of watches at Fund Verify are simply unmatched. The staff was not only knowledgeable but also passionate about helping me find the perfect timepiece. I couldn't be more satisfied with my purchase and the overall experience!",
  "Working with Fund Verify has been a game-changer for our business. Their attention to detail, exceptional customer service, and commitment to excellence have helped us achieve our goals more effectively. We highly recommend their services to anyone looking to grow their business.",
  "Our company was in dire need of a robust IT infrastructure overhaul, and Fund Verify delivered beyond our expectations. Their team of experts assessed our needs meticulously and implemented solutions that not only resolved our issues but also optimized our operations. The professionalism and expertise displayed were outstanding. We highly recommend Fund Verify for any tech solutions!",
];

export default function Testimonials() {
  const testimonialSwiperRef = useRef(null);
  const valuesSwiperRef = useRef(null);
  const [preious, setPreious] = useState(false);
  const [next, setNext] = useState(false);
  const [selectedCustomerIndex, setSelectedCustomerIndex] = useState(0);

  const handlePrevSlide = () => {
    const newIndex =
      (selectedCustomerIndex - 1 + customers.length) % customers.length;
    setSelectedCustomerIndex(newIndex);
    if (testimonialSwiperRef.current && testimonialSwiperRef.current.swiper) {
      testimonialSwiperRef.current.swiper.slidePrev();
    }
    if (valuesSwiperRef.current && valuesSwiperRef.current.swiper) {
      valuesSwiperRef.current.swiper.slidePrev();
    }
    setPreious(true);
    setTimeout(() => {
      setPreious(false);
    }, 200);
  };

  const handleNextSlide = () => {
    const newIndex = (selectedCustomerIndex + 1) % customers.length;
    setSelectedCustomerIndex(newIndex);
    if (testimonialSwiperRef.current && testimonialSwiperRef.current.swiper) {
      testimonialSwiperRef.current.swiper.slideNext();
    }
    if (valuesSwiperRef.current && valuesSwiperRef.current.swiper) {
      valuesSwiperRef.current.swiper.slideNext();
    }
    setNext(true);
    setTimeout(() => {
      setNext(false);
    }, 200);
  };

  const handleCustomerClick = (index) => {
    setSelectedCustomerIndex(index);
    if (valuesSwiperRef.current && valuesSwiperRef.current.swiper) {
      valuesSwiperRef.current.swiper.slideToLoop(index);
    }
  };

  return (
    <>
      <div className="w-full valuesBg md:px-20 py-14 pt-20">
        <div className="container mx-auto flex flex-row gap-10 items-center">
          <div className="w-[30%] md:text-21xl text-right text-white">
            <div className="my-5 h-[470px] flex flex-col gap-3 items-center justify-center">
              <div
                onClick={handlePrevSlide}
                className={`rounded cursor-pointer flex items-center justify-center ${
                  preious
                    ? "bg-white"
                    : "[background:linear-gradient(90deg,_#a2913e,_#d7c590_35.28%,_#a2913e_68.99%,_#d7c58f)]"
                } w-full py-2`}
              >
                <Image
                  height={30}
                  width={30}
                  className={`max-w-full overflow-hidden max-h-full ${
                    preious ? "filter invert" : ""
                  }`}
                  alt=""
                  src={upArrow.src}
                />
              </div>
              <Swiper
                ref={testimonialSwiperRef}
                spaceBetween={10}
                modules={[Pagination, Navigation, HashNavigation]}
                className="mySwiper testmonialSlider w-full h-full"
                direction={"vertical"}
                slidesPerView={3}
                loop={true}
              >
                {customers.map((customer, index) => (
                  <SwiperSlide key={index}>
                    <div
                      className={`mainDiv w-full flex rounded-md p-3 px-5 cursor-pointer ${
                        selectedCustomerIndex === index
                          ? "bg-white"
                          : "bg-[#ffffffa1]"
                      }`}
                      onClick={() => handleCustomerClick(index)}
                    >
                      <div className="inline-block">
                        <Image
                          height={78}
                          width={78}
                          className="rounded-full w-[78px] h-[78px] object-cover opacity-100"
                          alt={customer.name}
                          src={customer.image.src}
                        />
                      </div>
                      <div className="flex text-black justify-center ml-5 flex-col items-start">
                        <div className="text-2xl text-black font-medium select-none">
                          {customer.name}
                        </div>
                        <p className="text-lg select-none">{customer.role}</p>
                      </div>
                    </div>
                  </SwiperSlide>
                ))}
              </Swiper>
              <div
                onClick={handleNextSlide}
                className={`rounded cursor-pointer flex items-center justify-center ${
                  next
                    ? "bg-white"
                    : "[background:linear-gradient(90deg,_#a2913e,_#d7c590_35.28%,_#a2913e_68.99%,_#d7c58f)]"
                } w-full py-2`}
              >
                <Image
                  height={30}
                  width={30}
                  className={`max-w-full overflow-hidden max-h-full ${
                    next ? "filter invert" : ""
                  }`}
                  alt=""
                  src={downArrow.src}
                />
              </div>
            </div>
          </div>
          <div className="w-[70%] my-5 h-[470px] flex flex-col gap-3 items-center justify-center">
            <Swiper
              ref={valuesSwiperRef}
              spaceBetween={10}
              modules={[Pagination, Navigation, HashNavigation]}
              className="mySwiper testmonialSlider w-full h-full"
              direction={"vertical"}
              slidesPerView={1}
              loop={true}
              initialSlide={selectedCustomerIndex}
            >
              {testimonials.map((comment, index) => (
                <SwiperSlide
                  key={index}
                  className="!flex items-center justify-center"
                >
                  <div className="flex flex-col items-start text-white p-10">
                    <b className="text-5xl tracking-wide">Testimonials</b>
                    <div className="flex flex-row my-5 gap-2">
                      <div className="rounded-2xl bg-[#8D7C3B] w-[31.8px] h-[5.6px]" />
                      <div className="rounded-lg bg-white w-[84.9px] h-[5.6px]" />
                    </div>
                    <div className="text-2xl leading-[30px] font-medium inline-block h-[29px]">
                      {customers[selectedCustomerIndex].name}
                    </div>
                    <div className="flex flex-row gap-2 my-3">
                      <Image width={25} height={25} src={star.src} />
                      <Image width={25} height={25} src={star.src} />
                      <Image width={25} height={25} src={star.src} />
                      <Image width={25} height={25} src={star.src} />
                      <Image width={25} height={25} src={star.src} />
                    </div>
                    <p className="text-xl leading-[32px] text-left">
                      {comment}
                    </p>
                  </div>
                </SwiperSlide>
              ))}
            </Swiper>
          </div>
        </div>
      </div>
    </>
  );
}
